## Typing stubs for xmldiff

This is a [type stub package](https://typing.python.org/en/latest/tutorials/external_libraries.html)
for the [`xmldiff`](https://github.com/Shoobx/xmldiff) package. It can be used by type checkers
to check code that uses `xmldiff`. This version of
`types-xmldiff` aims to provide accurate annotations for
`xmldiff==2.7.*`.

This package is part of the [typeshed project](https://github.com/python/typeshed).
All fixes for types and metadata should be contributed there.
See [the README](https://github.com/python/typeshed/blob/main/README.md)
for more details. The source for this package can be found in the
[`stubs/xmldiff`](https://github.com/python/typeshed/tree/main/stubs/xmldiff)
directory.

This package was tested with the following type checkers:
* [mypy](https://github.com/python/mypy/) 1.18.2
* [pyright](https://github.com/microsoft/pyright) 1.1.406

It was generated from typeshed commit
[`058aa6246b9c5b61267dadf1ea25b7040960d86a`](https://github.com/python/typeshed/commit/058aa6246b9c5b61267dadf1ea25b7040960d86a).